# PHOXENE SxIP drivers

![Build Status](https://img.shields.io/pypi/v/sxip_drivers.svg)
![python](https://img.shields.io/pypi/pyversions/sxip_drivers.svg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/sxip-drivers/badge/?version=main)](https://sxip-drivers.readthedocs.io/)

![Phoxene Logo](https://www.phoxene.com/wp-content/uploads/2018/09/flash-strobe-manufacturer-phoxene.png)

This module implements basic drivers that can be used to manage PHOXENE's flash devices

# Usage
This module is intended to be use by software developpers in order to speed-up the integration
of PHOXENE's flash devices by our customers.

# Documentation
https://sxip-drivers.readthedocs.io/en/main/

# Installation
```shell
pip install -i https://pypi.org/simple/ sxip-drivers
```

# Dependencies
* phox-modbus

# Compatibility
Tested on Windows 10 and Debian 12.2

![Windows Logo](https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white)
![Debian Logo](https://img.shields.io/badge/Debian-A81D33?style=for-the-badge&logo=debian&logoColor=white)

# Licence
MIT License Copyright (c) 2024 PHOXENE

See LICENSE file

# Authors
written by Aurélien PLANTIN <a.plantin@phoxene.com>